@@ -2,9 +2,7 @@ context("canvasXpress data-url")
 
 if (interactive()) {
     test_that("Barplot URL data", {
-        result <- canvasXpress(data             = "https://www.canvasxpress.org/data/cX-generic-dat.txt",
-                               smpAnnot         = "https://www.canvasxpress.org/data/cX-generic-smp.txt",
-                               varAnnot         = "https://www.canvasxpress.org/data/cX-generic-var.txt",
+        result <- canvasXpress(data             = "https://www.canvasxpress.org/data/r/cX-generic-dat.txt",
                                graphType        = "Bar",
                                graphOrientation = "vertical",
                                plotByVariable   = TRUE,
